from UcsSdk import *
from UcsSdk.MoMeta.LsServer import LsServer
from rin.config import Config

import json
import os,sys

DEFAULT_PATH = '/usr/local/etc/rin-ucs.yml'

def get_blade_info(opts):
    handle = UcsHandle()

    def _filter(data):
        return not data.Name == 'ESXi'

    try:
        handle.Login(opts['server'], opts['userid'], opts['passwd'])
        ret = [{
            'name': blade.Name,
            'location': ' / '.join(blade.PnDn.split('/')[1:]),
            'status': blade.OperState,
            'manager': "UCS:%s" % (opts['server']),
            'type': 'PhysicalMachine'
            } for blade in handle.GetManagedObject(None, LsServer.ClassId()) if _filter(blade)]

        handle.Logout()
    except Exception, err:
        print "Runtime error: %s" % str(err)
        handle.Logout()

    return ret

def main():
    blades = []
    path = DEFAULT_PATH
    if 'RIN_CONFIG' in os.environ:
        path = os.environ['RIN_CONFIG']

    conf = Config.load(path)
    if conf == None:
        sys.exit(1)

    for manager_info in conf['ucs']:
        blades += get_blade_info(manager_info)

    print json.dumps(blades)



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='rin-driver-ucs',

    version='0.0.13',

    description='A command line utilities to operate UCS manager.',
    long_description=long_description,

    url='',

    author='Hiroyasu OHYAMA',
    author_email='oyama-hiroyasu@dmm.com',

    license='MIT',

    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    install_requires=['rin-common'],

    data_files=[('etc', ['data/rin-ucs.yml.example'])],

    entry_points={
        'console_scripts': [
            'ucs_list_servers=rin_ucs.list_servers:main',
        ],
    },
)
